==> react-bootstrap-table-1.2.9.jar: META-INF/resources/webjars/react-bootstrap-table/1.2.9/lib/util.js <==
'use strict';

Object.defineProperty(exports, '__esModule', {
  value: true
});

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _Const = require('./Const');

var _Const2 = _interopRequireDefault(_Const);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

exports['default'] = {

  renderSortCaret: function renderSortCaret(order) {
    var wrap = document.createElement("span");
    wrap.className = "order";
    if (order == _Const2['default'].SORT_ASC) wrap.className += " dropup";
    var inner = document.createElement("span");
    inner.className = "caret";
    inner.style.margin = "10px 5px";
    wrap.appendChild(inner);
    return wrap;
  },

  renderReactSortCaret: function renderReactSortCaret(order) {
    var orderClass = (0, _classnames2['default'])("order", {
      'dropup': order == _Const2['default'].SORT_ASC
    });
    return _react2['default'].createElement(
      'span',
      { className: orderClass },
      _react2['default'].createElement('span', { className: 'caret', style: { margin: '10px 5px' } })
    );
  },

  getScrollBarWidth: function getScrollBarWidth() {
    var inner = document.createElement('p');
    inner.style.width = "100%";
    inner.style.height = "200px";

    var outer = document.createElement('div');
    outer.style.position = "absolute";
    outer.style.top = "0px";
    outer.style.left = "0px";
    outer.style.visibility = "hidden";
    outer.style.width = "200px";
    outer.style.height = "150px";
    outer.style.overflow = "hidden";
    outer.appendChild(inner);

    document.body.appendChild(outer);
    var w1 = inner.offsetWidth;
    outer.style.overflow = 'scroll';
    var w2 = inner.offsetWidth;
    if (w1 == w2) w2 = outer.clientWidth;

    document.body.removeChild(outer);

    return w1 - w2;
  }

};
module.exports = exports['default'];

==> react-bootstrap-table-2.0.3.jar: META-INF/resources/webjars/react-bootstrap-table/2.0.3/lib/util.js <==
'use strict';

Object.defineProperty(exports, '__esModule', {
  value: true
});

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _Const = require('./Const');

var _Const2 = _interopRequireDefault(_Const);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

exports['default'] = {
  renderReactSortCaret: function renderReactSortCaret(order) {
    var orderClass = (0, _classnames2['default'])('order', {
      'dropup': order === _Const2['default'].SORT_ASC
    });
    return _react2['default'].createElement(
      'span',
      { className: orderClass },
      _react2['default'].createElement('span', { className: 'caret', style: { margin: '0px 5px' } })
    );
  },

  getScrollBarWidth: function getScrollBarWidth() {
    var inner = document.createElement('p');
    inner.style.width = '100%';
    inner.style.height = '200px';

    var outer = document.createElement('div');
    outer.style.position = 'absolute';
    outer.style.top = '0px';
    outer.style.left = '0px';
    outer.style.visibility = 'hidden';
    outer.style.width = '200px';
    outer.style.height = '150px';
    outer.style.overflow = 'hidden';
    outer.appendChild(inner);

    document.body.appendChild(outer);
    var w1 = inner.offsetWidth;
    outer.style.overflow = 'scroll';
    var w2 = inner.offsetWidth;
    if (w1 === w2) w2 = outer.clientWidth;

    document.body.removeChild(outer);

    return w1 - w2;
  },

  canUseDOM: function canUseDOM() {
    return typeof window !== 'undefined' && typeof window.document !== 'undefined';
  }
};
module.exports = exports['default'];
